<?php
namespace BWDPBProgressBar;

use bwdpbProgressBar\PageSettings\Page_Settings;
define( "BWDPB_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDPB_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );
class ClassBWDPBProgressBar {

	private static $_instance = null;
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdpb_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdpb_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdpb_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdpb_the_progressBar_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdpb-progressBar.php' );
	}

	public function bwdpb_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDPBProgressBarWidget() );

	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/progressBar-manager.php' );
		new Page_Settings();
	}


	// Register Category
	function bwdpb_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdpb-progressBar-category',
			[
				'title' => esc_html__( 'BWD progressBar', 'bwdpb-progressBar' ),
				'icon' => 'eicon-person',
			]
		);
	}

	public function bwdpb_all_assets_for_the_public(){
		wp_enqueue_style( 'bwdpb_fontAwesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.8.2/css/all.min.css', array(), '5.8.2', 'all' );
		wp_enqueue_script( 'bwdpb_bootstrap_bundle', 'https://cdnjs.cloudflare.com/ajax/libs/bootstrap/5.2.1/js/bootstrap.bundle.min.js', array(), '5.2.1', true );
		$all_css_js_file = array(

            'bwdpb_progressBar_style_css' => array('bwdpb_path_define'=>BWDPB_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css'),

			'bwdpb_progressBar_responsive_css' => array('bwdpb_path_define'=>BWDPB_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/responsive.css'),

            'bwdpb_progressBar_custom_js' => array('bwdpb_path_define'=>BWDPB_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/js/custom.js'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdpb_path_define'], null, '1.0', 'all');
            wp_enqueue_script( $handle, $fileinfo['bwdpb_path_define'], ['jquery'], '1.0', true);
        }
	}

	public function bwdpb_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdpb_progressBar_admin_icon_css' => array('bwdpb_path_admin_define'=>BWDPB_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );

        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdpb_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdpb_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdpb_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdpb_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdpb_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdpb_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
ClassBWDPBProgressBar::instance();